componenttools.remove_component_subtree_from_score_and_spanners
===============================================================

.. autofunction:: abjad.tools.componenttools.remove_component_subtree_from_score_and_spanners.remove_component_subtree_from_score_and_spanners
